Nebulex.Adapters.Mnesia.Cluster (nebulex_mnesia_adapter v2.6.5)

This module manages Mnesia cluster nodes and table copies. It monitors node up and down events to ensure that table copies are added or removed as needed.

Summary

Functions

Returns a specification to start this module under a supervisor.

Callback implementation for GenServer.init/1.

Functions

child_spec(init_arg)

Returns a specification to start this module under a supervisor.

See Supervisor.

init(opts)

Callback implementation for GenServer.init/1.

start_link(opts)